CastDevice class

Constructors

CastDevice({String? name, String? type, String? host, int? port, Map<String, Uint8List?>? attr})

Properties

attr → Map<String, Uint8List?>?
Contains the information about the device. You can decode with utf8 a bunch of information
final
deviceType → CastDeviceType
no setter
friendlyName → String?
no setter
googleModelType → GoogleCastModelType
no setter
hashCode → int
The hash code for this object.
no setterinherited
host → String?
final
log → Logger
final
modelName → String?
no setter
name → String?
final
port → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final

Methods

initDeviceInfo() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited