CastSession class

Constructors

CastSession({String? sourceId, String? destinationId, bool isConnected = false})

Properties

castMediaStatus ↔ CastMediaStatus?
getter/setter pair
destinationId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isConnected ↔ bool
getter/setter pair
isReadyForMedia ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceId ↔ String?
getter/setter pair

Methods

mergeWithChromeCastSessionMap(Map map) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, String?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited